pub struct GLKMatrixStack { /* private fields */ }The OpenGL API is deprecated by Apple
GLKMatrixStack only.Expand description
Implementations
Sourceimpl GLKMatrixStack
impl GLKMatrixStack
pub unsafe fn new( alloc: Option<&CFAllocator>, ) -> Option<CFRetained<GLKMatrixStack>>
The OpenGL API is deprecated by Apple
objc2-core-foundation only.Sourceimpl GLKMatrixStack
impl GLKMatrixStack
pub unsafe fn push(&self)
The OpenGL API is deprecated by Apple
pub unsafe fn pop(&self)
The OpenGL API is deprecated by Apple
pub unsafe fn size(&self) -> c_int
The OpenGL API is deprecated by Apple
pub unsafe fn load_matrix4(&self, matrix: GLKMatrix4)
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix4(&self) -> GLKMatrix4
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix3(&self) -> GLKMatrix3
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix2(&self) -> GLKMatrix2
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix4_inverse(&self) -> GLKMatrix4
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix4_inverse_transpose(&self) -> GLKMatrix4
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix3_inverse(&self) -> GLKMatrix3
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn matrix3_inverse_transpose(&self) -> GLKMatrix3
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn multiply_matrix4(&self, matrix: GLKMatrix4)
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn multiply_matrix_stack(&self, stack_right: &GLKMatrixStack)
The OpenGL API is deprecated by Apple
pub unsafe fn translate(&self, tx: c_float, ty: c_float, tz: c_float)
The OpenGL API is deprecated by Apple
pub unsafe fn translate_with_vector3(&self, translation_vector: GLKVector3)
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn translate_with_vector4(&self, translation_vector: GLKVector4)
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn scale(&self, sx: c_float, sy: c_float, sz: c_float)
The OpenGL API is deprecated by Apple
pub unsafe fn scale_with_vector3(&self, scale_vector: GLKVector3)
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn scale_with_vector4(&self, scale_vector: GLKVector4)
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn rotate( &self, radians: c_float, x: c_float, y: c_float, z: c_float, )
The OpenGL API is deprecated by Apple
pub unsafe fn rotate_with_vector3( &self, radians: c_float, axis_vector: GLKVector3, )
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn rotate_with_vector4( &self, radians: c_float, axis_vector: GLKVector4, )
The OpenGL API is deprecated by Apple
GLKMathTypes only.pub unsafe fn rotate_x(&self, radians: c_float)
The OpenGL API is deprecated by Apple
pub unsafe fn rotate_y(&self, radians: c_float)
The OpenGL API is deprecated by Apple
pub unsafe fn rotate_z(&self, radians: c_float)
The OpenGL API is deprecated by Apple
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.